
let args = process.argv
let params = args.slice(2)
let parentPid = params[1]
let rootPath = params[0]
let entryPath = params[2]

let logfile = `${rootPath}/.hvigor/outputs/build-logs/build.log`
let fs = require('fs')


function checkProcessExists(pid) {
    try {
        process.kill(pid, 0); // 尝试发送信号 0
        console.log(`进程 ${pid} 存在。`);
        return true;
    } catch (e) {
        if (e.code === 'ESRCH') {
            // ESRCH 错误码表示没有找到对应的进程
            console.log(`进程 ${pid} 不存在。`);
        } else if (e.code === 'EPERM') {
            // EPERM 错误码表示没有权限向该进程发送信号
            console.log(`没有权限检查进程 ${pid}，但它可能存在。`);
        } else {
            console.log(`检查进程时发生错误: ${e}`);
        }
        return false;
    }
}

// 监听当前进程是否存在
let parentProcessKilled = -1
let compiledFinished = false
let timeoutMax = 1*60*1000 // 超时3分钟
let currentTime = 0
let interval = setInterval(()=>{
    if (!checkProcessExists(parentPid)) {
        // 如果编译进程已经销毁，就标记下
        parentProcessKilled = 0
    }
    if (parentProcessKilled == 0) {
        // 如果主编译进程退出，超过超时时间，则进程退出
        if (currentTime >= timeoutMax) {
            backupReStore()
            // 直接退出当前进程
            process.exit(0)
        }

        if (compiledFinished) {
            // 如果编译经完成，直接推出
            parentProcessKilled = 1
            process.exit(0)
        } else {
            // 累加时间
            currentTime+=200
        }
    }
}, 200)



// 清空当前日志
fs.writeFileSync(logfile, "")
fs.watch(logfile, (eventType, filename) => {
    console.log(logfile)
    let ct = fs.readFileSync(logfile).toString()
    if ((ct.indexOf("BUILD SUCCESSFUL") >= 0) ||
        ct.indexOf("BUILD FAILED") >= 0) {
        // 无论编译成功、失败，都要进行文件还原
        backupReStore()
        compiledFinished = true
    }
});

let backupReStore = () => {
    let _hRoutePath = `${entryPath}/src/main/ets/_hRouter`
    let tmp = `${entryPath}/__tmp`
    let backupjson = `${tmp}/__backupjson`
    let json = JSON.parse(fs.readFileSync(backupjson).toString())
    for (let key in json) {
        let item = json[key]
        fs.copyFileSync(item.backup, item.source)
    }
    // 移除临时文件
    fs.rmSync(tmp, { recursive: true })
    fs.rmSync(_hRoutePath, { recursive: true })
}
